Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Commands = map[string]*Command{}
Commands defines all of the commands.
var DefaultPrefix = os.Getenv("DEFAULT_PREFIX")
DefaultPrefix defines the default prefix which the bot uses.
Functions ¶
Types ¶
type Command ¶
type Command struct {
Description string `json:"description"`
Usage string `json:"usage"`
Category *categories.Category `json:"category"`
PermissionsCheck func(Args *CommandArgs) (bool, string) `json:"-"`
Function func(Args *CommandArgs) `json:"-"`
}
Command is the structure which all commands will follow.
Click to show internal directories.
Click to hide internal directories.